# 🦜🧙 langcraft

[![PyPI](https://img.shields.io/pypi/v/langcraft.svg)](https://pypi.org/project/langcraft/) [![Changelog](https://img.shields.io/github/v/release/0d431/langcraft?include_prereleases&label=changelog)](https://github.com/0d431/langcraft/releases) [![Tests](https://img.shields.io/github/actions/workflow/status/0d431/langcraft/run_tests.yml)](https://github.com/0d431/langcraft/actions/workflows/run_tests.yml) [![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://github.com/0d431/langcraft/blob/main/LICENSE)

This is a lightweight framework to abstract common LLMs for completion, supporting vision and function calling into native Python.
